@@ -1,10 +1,11 @@
 from jsonschema import validate
 import json
+import pkgutil
 
 
 def test_validate(instance):
-    with open('test_schema.json', 'r') as schema_file:
-        schema = json.load(schema_file)
+    resources = pkgutil.get_data('hero', 'test_schema.json')
+    schema = json.loads(resources)
     validate(instance, schema)
 
 
